couchdb.view

Package couchdb :: Module view |

# Module view

Implementation of a view server for functions written in Python.

Functions
run(input=sys.stdout, output=sys.stdout) CouchDB view function handler implementation for Python. |
main() Command-line entry point for running the view server. |

Function Details

### run(input=sys.stdout, output=sys.stdout) |
CouchDB view function handler implementation for Python. Parameters: `input` - the readable file-like object to read input from `output` - the writable file-like object to write output to